@@ -20,6 +20,7 @@ from pyteal.ast.txn import (
     Txn,
 )
 from pyteal.ast.gtxn import GtxnExpr, GtxnaExpr, TxnGroup, Gtxn
+from pyteal.ast.block import Block
 from pyteal.ast.gaid import GeneratedID
 from pyteal.ast.gitxn import Gitxn, GitxnExpr, GitxnaExpr, InnerTxnGroup
 from pyteal.ast.gload import ImportScratchValue
@@ -51,6 +52,7 @@ from pyteal.ast.unaryexpr import (
     BitLen,
     Sha256,
     Sha512_256,
+    Sha3_256,
     Keccak256,
     Not,
     BitwiseNot,
@@ -102,10 +104,22 @@ from pyteal.ast.binaryexpr import (
     ExtractUint32,
     ExtractUint64,
 )
+from pyteal.ast.base64decode import Base64Decode
 
 # ternary ops
-from pyteal.ast.ternaryexpr import Divw, Ed25519Verify, SetBit, SetByte
+from pyteal.ast.ternaryexpr import (
+    Divw,
+    Ed25519Verify,
+    Ed25519Verify_Bare,
+    SetBit,
+    SetByte,
+)
 from pyteal.ast.substring import Substring, Extract, Suffix
+from pyteal.ast.replace import Replace
+from pyteal.ast.jsonref import JsonRef
+
+# quaternary ops
+from pyteal.ast.vrfverify import VrfVerify
 
 # more ops
 from pyteal.ast.naryexpr import NaryExpr, Add, And, Mul, Or, Concat
@@ -175,6 +189,7 @@ __all__ = [
     "GtxnaExpr",
     "TxnGroup",
     "Gtxn",
+    "Block",
     "GeneratedID",
     "ImportScratchValue",
     "Global",
@@ -208,6 +223,7 @@ __all__ = [
     "BitLen",
     "Sha256",
     "Sha512_256",
+    "Sha3_256",
     "Keccak256",
     "Not",
     "BitwiseNot",
@@ -237,6 +253,7 @@ __all__ = [
     "GetBit",
     "GetByte",
     "Ed25519Verify",
+    "Ed25519Verify_Bare",
     "Substring",
     "Extract",
     "Suffix",
@@ -292,6 +309,8 @@ __all__ = [
     "ExtractUint16",
     "ExtractUint32",
     "ExtractUint64",
+    "Replace",
+    "Base64Decode",
     "Log",
     "While",
     "For",
@@ -307,4 +326,6 @@ __all__ = [
     "EcdsaVerify",
     "EcdsaDecompress",
     "EcdsaRecover",
+    "JsonRef",
+    "VrfVerify",
 ]
