@@ -4,9 +4,9 @@ import pyteal as pt
 from pyteal.ast.txn import TxnField, TxnType
 from pyteal.types import types_match
 
-teal4Options = pt.CompileOptions(version=4)
-teal5Options = pt.CompileOptions(version=5)
-teal6Options = pt.CompileOptions(version=6)
+avm4Options = pt.CompileOptions(version=4)
+avm5Options = pt.CompileOptions(version=5)
+avm6Options = pt.CompileOptions(version=6)
 
 
 def test_InnerTxnBuilder_Begin():
@@ -16,12 +16,12 @@ def test_InnerTxnBuilder_Begin():
 
     expected = pt.TealSimpleBlock([pt.TealOp(expr, pt.Op.itxn_begin)])
 
-    actual, _ = expr.__teal__(teal5Options)
+    actual, _ = expr.__teal__(avm5Options)
 
     assert actual == expected
 
     with pytest.raises(pt.TealInputError):
-        expr.__teal__(teal4Options)
+        expr.__teal__(avm4Options)
 
 
 def test_InnerTxnBuilder_Submit():
@@ -31,12 +31,12 @@ def test_InnerTxnBuilder_Submit():
 
     expected = pt.TealSimpleBlock([pt.TealOp(expr, pt.Op.itxn_submit)])
 
-    actual, _ = expr.__teal__(teal5Options)
+    actual, _ = expr.__teal__(avm5Options)
 
     assert actual == expected
 
     with pytest.raises(pt.TealInputError):
-        expr.__teal__(teal4Options)
+        expr.__teal__(avm4Options)
 
 
 def test_InnerTxnBuilder_Next():
@@ -46,12 +46,12 @@ def test_InnerTxnBuilder_Next():
 
     expected = pt.TealSimpleBlock([pt.TealOp(expr, pt.Op.itxn_next)])
 
-    actual, _ = expr.__teal__(teal6Options)
+    actual, _ = expr.__teal__(avm6Options)
 
     assert actual == expected
 
     with pytest.raises(pt.TealInputError):
-        expr.__teal__(teal5Options)
+        expr.__teal__(avm5Options)
 
 
 def test_InnerTxnBuilder_SetField():
@@ -83,14 +83,14 @@ def test_InnerTxnBuilder_SetField():
                 ]
             )
 
-            actual, _ = expr.__teal__(teal5Options)
+            actual, _ = expr.__teal__(avm5Options)
             actual.addIncoming()
             actual = pt.TealBlock.NormalizeBlocks(actual)
 
             assert actual == expected
 
             with pytest.raises(pt.TealInputError):
-                expr.__teal__(teal4Options)
+                expr.__teal__(avm4Options)
 
 
 ITXN_FIELDS_CASES = [
@@ -120,11 +120,11 @@ def test_InnerTxnBuilder_SetFields():
         assert expr.type_of() == pt.TealType.none
         assert not expr.has_return()
 
-        expected, _ = expectedExpr.__teal__(teal5Options)
+        expected, _ = expectedExpr.__teal__(avm5Options)
         expected.addIncoming()
         expected = pt.TealBlock.NormalizeBlocks(expected)
 
-        actual, _ = expr.__teal__(teal5Options)
+        actual, _ = expr.__teal__(avm5Options)
         actual.addIncoming()
         actual = pt.TealBlock.NormalizeBlocks(actual)
 
@@ -133,7 +133,7 @@ def test_InnerTxnBuilder_SetFields():
 
         if len(fields) != 0:
             with pytest.raises(pt.TealInputError):
-                expr.__teal__(teal4Options)
+                expr.__teal__(avm4Options)
 
 
 def test_InnerTxnBuilder_Execute():
@@ -144,11 +144,11 @@ def test_InnerTxnBuilder_Execute():
             pt.InnerTxnBuilder.Begin(),
             expectedExpr,
             pt.InnerTxnBuilder.Submit(),
-        ).__teal__(teal5Options)
+        ).__teal__(avm5Options)
         expected.addIncoming()
         expected = pt.TealBlock.NormalizeBlocks(expected)
 
-        actual, _ = expr.__teal__(teal5Options)
+        actual, _ = expr.__teal__(avm5Options)
         actual.addIncoming()
         actual = pt.TealBlock.NormalizeBlocks(actual)
 
@@ -156,7 +156,7 @@ def test_InnerTxnBuilder_Execute():
             assert actual == expected
 
         with pytest.raises(pt.TealInputError):
-            expr.__teal__(teal4Options)
+            expr.__teal__(avm4Options)
 
 
 ITXN_METHOD_CASES = (
@@ -423,11 +423,11 @@ def test_InnerTxnBuilder_method_call(
     assert expr.type_of() == pt.TealType.none
     assert not expr.has_return()
 
-    expected, _ = expected_expr.__teal__(teal6Options)
+    expected, _ = expected_expr.__teal__(avm6Options)
     expected.addIncoming()
     expected = pt.TealBlock.NormalizeBlocks(expected)
 
-    actual, _ = expr.__teal__(teal6Options)
+    actual, _ = expr.__teal__(avm6Options)
     actual.addIncoming()
     actual = pt.TealBlock.NormalizeBlocks(actual)
 
@@ -439,4 +439,240 @@ def test_InnerTxnBuilder_method_call(
         )
 
 
+ITXN_METHOD_CASES = (
+    (
+        pt.Int(1),
+        "add(uint64,uint64)void",
+        [t1_1 := pt.Itob(pt.Int(1)), t1_2 := pt.Itob(pt.Int(1))],
+        {TxnField.fee: pt.Int(0)},
+        pt.Seq(
+            pt.InnerTxnBuilder.SetFields(
+                {
+                    pt.TxnField.type_enum: TxnType.ApplicationCall,
+                    pt.TxnField.application_id: pt.Int(1),
+                    pt.TxnField.application_args: [
+                        pt.MethodSignature("add(uint64,uint64)void"),
+                        t1_1,
+                        t1_2,
+                    ],
+                    pt.TxnField.fee: pt.Int(0),
+                }
+            ),
+        ),
+        None,
+    ),
+    (
+        pt.Int(1),
+        "add(uint64,uint64)void",
+        [t2_1 := pt.abi.Uint64(), t2_2 := pt.abi.Uint64()],
+        {TxnField.fee: pt.Int(0)},
+        pt.Seq(
+            pt.InnerTxnBuilder.SetFields(
+                {
+                    pt.TxnField.type_enum: TxnType.ApplicationCall,
+                    pt.TxnField.application_id: pt.Int(1),
+                    pt.TxnField.application_args: [
+                        pt.MethodSignature("add(uint64,uint64)void"),
+                        t2_1.encode(),
+                        t2_2.encode(),
+                    ],
+                    pt.TxnField.fee: pt.Int(0),
+                }
+            ),
+        ),
+        None,
+    ),
+    (
+        pt.Int(1),
+        "add(application,account,asset)void",
+        [
+            t3_1 := pt.abi.Application(),
+            t3_2 := pt.abi.Account(),
+            t3_3 := pt.abi.Asset(),
+        ],
+        {TxnField.fee: pt.Int(0)},
+        pt.Seq(
+            pt.InnerTxnBuilder.SetFields(
+                {
+                    pt.TxnField.type_enum: TxnType.ApplicationCall,
+                    pt.TxnField.application_id: pt.Int(1),
+                    pt.TxnField.accounts: [t3_2.address()],
+                    pt.TxnField.applications: [t3_1.application_id()],
+                    pt.TxnField.assets: [t3_3.asset_id()],
+                    pt.TxnField.application_args: [
+                        pt.MethodSignature("add(application,account,asset)void"),
+                        pt.Bytes(b"\x01"),
+                        pt.Bytes(b"\x01"),
+                        pt.Bytes(b"\x00"),
+                    ],
+                    pt.TxnField.fee: pt.Int(0),
+                }
+            ),
+        ),
+        None,
+    ),
+    (
+        pt.Int(1),
+        "add(application,account,asset)void",
+        [
+            t4_1 := pt.Int(1),
+            t4_2 := pt.Global.zero_address(),
+            t4_3 := pt.Int(2),
+        ],
+        {TxnField.fee: pt.Int(0)},
+        pt.Seq(
+            pt.InnerTxnBuilder.SetFields(
+                {
+                    pt.TxnField.type_enum: TxnType.ApplicationCall,
+                    pt.TxnField.application_id: pt.Int(1),
+                    pt.TxnField.accounts: [t4_2],
+                    pt.TxnField.applications: [t4_1],
+                    pt.TxnField.assets: [t4_3],
+                    pt.TxnField.application_args: [
+                        pt.MethodSignature("add(application,account,asset)void"),
+                        pt.Bytes(b"\x01"),
+                        pt.Bytes(b"\x01"),
+                        pt.Bytes(b"\x00"),
+                    ],
+                    pt.TxnField.fee: pt.Int(0),
+                }
+            ),
+        ),
+        None,
+    ),
+    (
+        pt.Int(1),
+        "add(pay,txn,appl)void",
+        [
+            t5_1 := {TxnField.type_enum: TxnType.Payment},
+            t5_2 := {TxnField.type_enum: TxnType.AssetTransfer},
+            t5_3 := {TxnField.type_enum: TxnType.ApplicationCall},
+        ],
+        {TxnField.fee: pt.Int(0)},
+        pt.Seq(
+            pt.InnerTxnBuilder.SetFields(t5_1),  # type: ignore
+            pt.InnerTxnBuilder.Next(),
+            pt.InnerTxnBuilder.SetFields(t5_2),  # type: ignore
+            pt.InnerTxnBuilder.Next(),
+            pt.InnerTxnBuilder.SetFields(t5_3),  # type: ignore
+            pt.InnerTxnBuilder.Next(),
+            pt.InnerTxnBuilder.SetFields(
+                {
+                    pt.TxnField.type_enum: TxnType.ApplicationCall,
+                    pt.TxnField.application_id: pt.Int(1),
+                    pt.TxnField.application_args: [
+                        pt.MethodSignature("add(pay,txn,appl)void"),
+                    ],
+                    pt.TxnField.fee: pt.Int(0),
+                }
+            ),
+        ),
+        None,
+    ),
+    # Error cases
+    (
+        pt.Int(1),
+        "add(pay,txn,appl)void",
+        [
+            {},
+            {TxnField.type_enum: TxnType.AssetTransfer},
+            {TxnField.type_enum: TxnType.ApplicationCall},
+        ],
+        None,
+        None,
+        pt.TealInputError,
+    ),
+    (
+        pt.Int(1),
+        "add(pay,txn,appl)void",
+        [
+            {TxnField.type_enum: pt.Int(10)},
+            {TxnField.type_enum: TxnType.AssetTransfer},
+            {TxnField.type_enum: TxnType.ApplicationCall},
+        ],
+        None,
+        None,
+        pt.TealTypeError,
+    ),
+    (
+        pt.Int(1),
+        "add(pay,txn,appl)void",
+        [
+            {TxnField.type_enum: TxnType.ApplicationCall},
+            {TxnField.type_enum: TxnType.AssetTransfer},
+            {TxnField.type_enum: TxnType.ApplicationCall},
+        ],
+        None,
+        None,
+        pt.TealInputError,
+    ),
+    (
+        pt.Int(1),
+        "add(application,account,asset)void",
+        [
+            pt.abi.Asset(),
+            pt.abi.Account(),
+            pt.abi.Asset(),
+        ],
+        None,
+        None,
+        pt.TealTypeError,
+    ),
+    (
+        pt.Int(1),
+        "add(application)void",
+        [
+            pt.Bytes(""),
+        ],
+        None,
+        None,
+        pt.TealTypeError,
+    ),
+    (
+        pt.Int(1),
+        "add(asset)void",
+        [
+            pt.Bytes(""),
+        ],
+        None,
+        None,
+        pt.TealTypeError,
+    ),
+    (
+        pt.Int(1),
+        "add(account)void",
+        [
+            pt.Int(1),
+        ],
+        None,
+        None,
+        pt.TealTypeError,
+    ),
+    (
+        pt.Int(1),
+        "add(uint64,uint64)void",
+        [pt.abi.String(), pt.abi.Uint64()],
+        None,
+        None,
+        pt.TealTypeError,
+    ),
+    (
+        pt.Int(1),
+        "add(uint64,uint64)void",
+        [pt.abi.Uint64()],
+        None,
+        None,
+        pt.TealInputError,
+    ),
+    (
+        pt.Int(1),
+        "add(uint64,uint64)void",
+        [pt.abi.Uint64(), pt.abi.Uint64(), pt.abi.Uint64()],
+        None,
+        None,
+        pt.TealInputError,
+    ),
+)
+
+
 # txn_test.py performs additional testing
