@@ -1,9 +1,14 @@
-from ..errors import TealInputError
-from .expr import Expr
-from ..ir import TealOp, Op
-from .seq import Seq
-from .bytes import Bytes
-from .unaryexpr import Pop
+from typing import TYPE_CHECKING
+
+from pyteal.errors import TealInputError
+from pyteal.ast.expr import Expr
+from pyteal.ast.seq import Seq
+from pyteal.ast.bytes import Bytes
+from pyteal.ast.unaryexpr import Pop
+
+if TYPE_CHECKING:
+    from pyteal.compiler import CompileOptions
+
 
 class Nonce(Expr):
     """A meta expression only used to change the hash of a TEAL program."""
@@ -20,6 +25,8 @@ class Nonce(Expr):
             nonce: An arbitrary nonce string that conforms to base.
             child: The expression to wrap.
         """
+        super().__init__()
+
         if base not in ("utf8", "base16", "base32", "base64"):
             raise TealInputError("Invalid base: {}".format(base))
 
@@ -29,16 +36,19 @@ class Nonce(Expr):
         else:
             self.nonce_bytes = Bytes(base, nonce)
 
-    def __teal__(self):
-        return Seq([
-            Pop(self.nonce_bytes),
-            self.child
-        ]).__teal__()
+        self.seq = Seq([Pop(self.nonce_bytes), self.child])
+
+    def __teal__(self, options: "CompileOptions"):
+        return self.seq.__teal__(options)
 
     def __str__(self):
-        return "(nonce: {}) {}".format(self.nonce_bytes.__str__(), self.child.__str__())
+        return "(nonce: {}) {}".format(self.nonce_bytes, self.child)
 
     def type_of(self):
         return self.child.type_of()
 
+    def has_return(self):
+        return self.child.has_return()
+
+
 Nonce.__module__ = "pyteal"
